@@ -31,7 +31,7 @@ except ImportError:
 
 have_mayavi = False
 try:
-     import mayavi
+     import mayavi.modules
      have_mayavi = True
 except ImportError:
      pass
@@ -108,8 +108,8 @@ class Viewer(ViewerParent):
     _model_name = Unicode('ViewerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.22.0').tag(sync=True)
-    _model_module_version = Unicode('^0.22.0').tag(sync=True)
+    _view_module_version = Unicode('^0.23.0').tag(sync=True)
+    _model_module_version = Unicode('^0.23.0').tag(sync=True)
     image = ITKImage(default_value=None, allow_none=True, help="Image to visualize.").tag(sync=False, **itkimage_serialization)
     rendered_image = ITKImage(default_value=None, allow_none=True).tag(sync=True, **itkimage_serialization)
     _rendering_image = CBool(default_value=False, help="We are currently volume rendering the image.").tag(sync=True)
@@ -604,10 +604,12 @@ def view(image=None,
 
         for a in actors:
             if have_mayavi:
+                from mayavi.modules import surface
+                from mayavi.modules import iso_surface
                 from tvtk.api import tvtk
-                if isinstance(a, mayavi.modules.surface.Surface):
+                if isinstance(a, surface.Surface):
                     a = tvtk.to_vtk(a.actor.actor)
-                elif isinstance(a, mayavi.modules.iso_surface.IsoSurface):
+                elif isinstance(a, iso_surface.IsoSurface):
                     a = tvtk.to_vtk(a.actor.actor)
 
             if isinstance(a, vtk.vtkAssembly): #unpack assemblies
